@@ -3,7 +3,7 @@
 /**
  *
  *
- * @version $Id: Config.class.php 11218 2008-04-29 11:44:42Z lem9 $
+ * @version $Id: Config.class.php 11441 2008-07-28 16:40:56Z lem9 $
  */
 
 /**
@@ -85,7 +85,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '2.11.6');
+        $this->set('PMA_VERSION', '2.11.8');
         /**
          * @deprecated
          */
@@ -178,6 +178,9 @@ class PMA_Config
                    && preg_match('@Safari/([0-9]*)@', $HTTP_USER_AGENT, $log_version2)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1] . '.' . $log_version2[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'SAFARI');
+        } elseif (preg_match('@rv:1.9(.*)Gecko@', $HTTP_USER_AGENT)) {
+            $this->set('PMA_USR_BROWSER_VER', '1.9');
+            $this->set('PMA_USR_BROWSER_AGENT', 'GECKO');
         } elseif (preg_match('@Mozilla/([0-9].[0-9]{1,2})@', $HTTP_USER_AGENT, $log_version)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'MOZILLA');
@@ -542,12 +545,14 @@ class PMA_Config
 
     /**
      * returns a unique value to force a CSS reload if either the config
-     * or the theme changes
+     * or the theme changes;
+     * must also check the pma_fontsize cookie in case there is no
+     * config file
      * @return  int  Unix timestamp
      */
     function getThemeUniqueValue()
     {
-        return intval($_SESSION['PMA_Config']->get('fontsize')) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info);
+        return intval((null !== $_SESSION['PMA_Config']->get('fontsize') ? $_SESSION['PMA_Config']->get('fontsize') : $_COOKIE['pma_fontsize'])) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info);
     }
 
     /**
@@ -1000,6 +1005,14 @@ class PMA_Config
     function getFontsizeSelection()
     {
         $current_size = $_SESSION['PMA_Config']->get('fontsize');
+        // for the case when there is no config file (this is supported)
+        if (empty($current_size)) {
+            if (isset($_COOKIE['pma_fontsize'])) {
+                $current_size = $_COOKIE['pma_fontsize'];
+            } else {
+                $current_size = '82%';
+            }
+        }
         $options = PMA_Config::getFontsizeOptions($current_size);
 
         $return = '<label for="select_fontsize">' . $GLOBALS['strFontSize'] . ':</label>' . "\n";
